@@ -8,8 +8,11 @@ R/W access to all private repositories of the company account.
 """
 
 # Created by Maximillian Dornseif on 2009-12-31 for HUDORA.
-# Copyright (c) 2009 HUDORA. All rights reserved.
-# BSD licensed
+# Copyright (C) 2009-2012 James Rowe <jnrowe@gmail.com>
+#                         Maximillian Dornseif <m.dornseif@hudora.de>
+#
+# This file is part of python-github2, and is made available under the 3-clause
+# BSD license.  See LICENSE for the full details.
 
 import logging
 import sys
@@ -24,9 +27,11 @@ PY3K = sys.version_info[0] == 3 and True or False
 
 
 def print_(text):
-    """Python 2 & 3 compatible print function
+    """Python 2 & 3 compatible print function.
 
-    We support <2.6, so can't use __future__.print_function"""
+    We support <2.6, so can't use __future__.print_function
+
+    """
     if PY3K:
         print(text)
     else:
@@ -34,7 +39,7 @@ def print_(text):
 
 
 def parse_commandline():
-    """Parse the comandline and return parsed options."""
+    """Parse the command line and return parsed options."""
 
     parser = OptionParser()
     parser.description = __doc__
@@ -73,7 +78,7 @@ def parse_commandline():
 
 
 def main():
-    """This implements the actual program functionality"""
+    """Implement the actual program functionality."""
 
     options, args = parse_commandline()
 
